@@ -1,4 +1,4 @@
-/*	$OpenBSD: extern.h,v 1.224 2024/06/08 13:30:35 tb Exp $ */
+/*	$OpenBSD: extern.h,v 1.226 2024/08/21 19:35:31 job Exp $ */
 /*
  * Copyright (c) 2019 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -831,7 +831,8 @@ void		 proc_http(char *, int) __attribute__((noreturn));
 void		 proc_rrdp(int) __attribute__((noreturn));
 
 /* Repository handling */
-int		 filepath_add(struct filepath_tree *, char *, int, time_t);
+int		 filepath_add(struct filepath_tree *, char *, int, time_t, int);
+int		 filepath_valid(struct filepath_tree *, char *, int);
 void		 rrdp_clear(unsigned int);
 void		 rrdp_session_save(unsigned int, struct rrdp_session *);
 void		 rrdp_session_free(struct rrdp_session *);
@@ -1017,7 +1018,7 @@ int	mkpathat(int, const char *);
 
 /* Min/Max acceptable file size */
 #define MIN_FILE_SIZE		100
-#define MAX_FILE_SIZE		4000000
+#define MAX_FILE_SIZE		8000000
 
 /* Maximum number of FileNameAndHash entries per RSC checklist. */
 #define MAX_CHECKLIST_ENTRIES	100000
